@@ -1,5 +1,5 @@
-import typing
 import contextlib
+import typing
 
 
 class BaseMethod:
@@ -17,7 +17,7 @@ class BaseMethod:
         self._api_key = api_key
         return self
 
-    def attach_shop_id(self, shop_id: int):
+    def attach_shop_id(self, shop_id: typing.Union[str, int]):
         self.kwargs["shop_id"] = shop_id
         return self
 
@@ -65,18 +65,6 @@ class UploadGoods(BaseMethod):
     json = ["product_id", "data", "shop_id"]
 
 
-class GetPurchases(BaseMethod):
-    http_method = "get"
-    path = "/v2/purchase/all"
-    params = ["user_id", "shop_id", "limit"]
-
-
-class GetShop(BaseMethod):
-    http_method = "get"
-    path = "/v2/shop"
-    params = ["shop_id"]
-
-
 class GetProducts(BaseMethod):
     http_method = "get"
     path = "/v2/product/all"
@@ -104,3 +92,9 @@ class DeleteProduct(BaseMethod):
     http_method = "delete"
     path = "/v2/product"
     json = ["id", "shop_id"]
+
+
+class GetCountPositionsInProduct(BaseMethod):
+    http_method = "get"
+    path = "/v2/product/count-positions"
+    params = ["product_id", "shop_id"]
